import { httpActivity ,httpImages,httpInfo} from "../../../api/serverResource";
import {
  createStoreBindings
} from 'mobx-miniprogram-bindings'
import {
  store
} from "../../../store/index";
Page({
  data: {
    addr: '北京市顺义区信中街12号院8号楼-1至4层101内三层309室',
    id: "",
    active: '',
    items: null,
    areaNum: 0,
    roomNum: 0,
    areaMin: 0,
    areaMax: 0,
    areaPnum: 0,
    cengban: [],
    huiyi: [],
    kefang: [],
    canting: [],
    imgList: [],
    joptions: [],
    hoptions: [],
    coptions: [],
    koptions: [],
    length: 0,
    showNum: false,
    showSS: false,
  },

  onLoad(options) {

    this.storeBindings = createStoreBindings(this, {
      store,
      fields: ["token"],
      actions: ["setStore"],
    });
    const {
      id
    } = options
    this.setData({
      id
    })
    this.getResourceDetails()
    this.getActivity()
    this.getAllImages()

  },
  onUnload() {
    this.storeBindings.destroyStoreBindings();
  },
  bindImgTap() {
    wx.navigateTo({
      url: "../resource-img/index?id=" + this.data.id
    })
  },

  bindAddrTap() {
    wx.getLocation({
      type: 'gcj02', //返回可以用于wx.openLocation的经纬度
      success(res) {
        const latitude = res.latitude
        const longitude = res.longitude
        wx.openLocation({
          latitude,
          longitude,
          scale: 200
        })
      }
    })
  },
  onFormChange(e) {
    const {
      url,
      title
    } = e.currentTarget.dataset
    if (url) {
      wx.navigateTo({
        url: "../cengban-url/index?url=" + url + "&title=" +
          title
      })

    }
  },


  async getActivity() {
    const {
      id
    } = this.data
    const arr = []
    const {
      code,
      data
    } = await httpActivity({
      store_id: id,
      page: 1,
      limit: 9999999
    })
    if (code === 1) {
      const {
        list
      } = data
      list.forEach(si => {
        arr.push({
          ...si,
          img: si.act_img === "" ? [] : si.act_img.split(",") || []
        });
      })
    }

    this.setData({
      cengban: arr
    })
  },
  async getAllImages() {
    const list1 = await this.getImages('会议室')
    const list2 = await this.getImages('客房')
    const list3 = await this.getImages('会议服务设施')
    const list4 = await this.getImages('详情图片')

    let areaNum = 0,
      roomNum = 0,
      areaMin = 0,
      areaMax = 0,
      areaPnum = 0;
    list2.forEach((s) => {
      roomNum += Number(s.length)
    })
    list1.forEach(s => {
      areaNum += Number(s.length)
      if (areaMin === 0 || areaMin !== 0 && Number(s.area) < areaMin) {
        areaMin = Number(s.area)
      }
      if (areaMax === 0 || areaMax !== 0 && Number(s.area) > areaMax) {
        areaMax = Number(s.area)
      }
      if (areaPnum === 0 || areaPnum !== 0 && Number(s.capacity) > areaPnum) {
        areaPnum = Number(s.capacity)
      }
    })

    this.setData({
      huiyi: list1,
      kefang: list2,
      canting: list3,
      imgList: list4,
      areaNum,
      roomNum,
      areaMin,
      areaMax,
      areaPnum,
      showNum: !(areaNum === 0 || roomNum === 0 || areaMax === 0 || areaPnum === 0)
    });
    let con = {
      huiyi: {
        value: '1',
        has_list: false,
      },
      kefang: {
        value: '2',
        has_list: false,
      },
      canting: {
        value: '3',
        has_list: false,
      },
      cengban: {
        value: '4',
        has_list: false,
      },
    }
    let len = this.data.length;
    let act = '';
    for (let key in con) {
      if (this.data[key].length > 0) {
        con[key].has_list = true
        len++
      }
    }
    for (let key in con) {
      if (con[key].has_list && act === '') {
        act = con[key].value
      }

    }
    const {
      showSS
    } = this.data
    this.setData({
      length: len,
      active: act !== "" ? act + '' : showSS ? '6' : '5'
    })
  },
  async getImages(type) {
    const {
      id
    } = this.data
    const {
      code,
      data
    } = await httpImages({
      store_id: id,
      page: 1,
      limit: 9999999,
      type
    })
    if (code !== 1) {
      await this.setStore("", "");
    }
    return code === 1 ? data.list : []
  },
  async getResourceDetails() {
    const {
      id
    } = this.data

    const {
      code,
      data
    } = await httpInfo({
      store_id: id,
    })
    if (code !== 1) {
      await this.setStore("", "");
    }
    const {
      row
    } = data
    const {
      caterer_spec_tags,
      conference_spec_tags,
      hotel_spec_tags,
      room_spec_tags,
      storeSpec,
      supplierStore,
      store_desc
    } = row

    // return code === 1 ? data.list : []
    const {
      store_name,
      store_image,
      store_city_text,
      map_addr,
      store_addr,
      type_id,
      type_text,


    } = supplierStore
    const model = {
      ...data.row || {},
      store_name,
      store_image,
      addr: store_city_text + store_addr,
      store_city_text,
      store_addr,
      map_addr,
      type_id,
      type_text,
      store_desc,
      store_spec_name: storeSpec.name || []
    }
    const showSS = caterer_spec_tags.length > 0 || conference_spec_tags.length > 0 || hotel_spec_tags.length > 0 || room_spec_tags.length > 0
    let length = 0
    if (String(store_desc) !== "") {
      length++
    }
    if (showSS) {
      length++
    }
    this.setData({
      items: model,
      joptions: caterer_spec_tags,
      hoptions: conference_spec_tags,
      coptions: hotel_spec_tags,
      koptions: room_spec_tags,
      showSS: showSS,
      length: length
    })
    if (code !== 1) {
      await this.setStore("", "");
    }
  },

})